@@ -9,10 +9,10 @@ use Cwd            ();
 use File::Basename ();
 use File::Path     ();
 use File::Spec     ();
-use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
+use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 has base_url      => '/packed/';
 has minify        => 0;
@@ -28,6 +28,7 @@ has _ua  => sub {
 sub add {
   my ($self, $moniker, @files) = @_;
 
+  @files = $self->_expand_wildcards(@files);
   return $self->tap(sub { $self->{files}{$moniker} = \@files }) if NO_CACHE;
   return $self->tap(sub { $self->_assets($moniker => $self->_process($moniker, @files)) }) if $self->minify;
   return $self->tap(sub { $self->_assets($moniker => $self->_process_many($moniker, @files)) });
@@ -65,6 +66,28 @@ sub preprocessor {
   return $self;
 }
 
+sub purge {
+  my ($self, $args) = @_;
+  my $file_re = $self->minify ? qr/^(.*?)-(\w{32})\.min\.(\w+)$/ : qr/^(.*?)-(\w{32})\.(\w+)$/;
+  my ($PACKED, %existing);
+
+  # default to not purging, unless in development mode
+  local $args->{always} = $args->{always} // $self->_app->mode eq 'development';
+
+  return $self unless $args->{always};
+  die '$app->asset->purge() must be called AFTER $app->asset(...)' unless keys %{$self->{assets} || {}};
+  return $self unless $self->out_dir and opendir $PACKED, $self->out_dir;
+  $existing{$_} = 1 for grep { $_ =~ $file_re } readdir $PACKED;
+  delete $existing{$_->basename} for map {@$_} values %{$self->{assets} || {}};
+
+  for my $file (keys %existing) {
+    $self->_unlink_packed($file);
+    warn "[ASSETPACK] Purged $file ($!)\n" if DEBUG;
+  }
+
+  return $self;
+}
+
 sub register {
   my ($self, $app, $config) = @_;
   my $helper = $config->{helper} || 'asset';
@@ -151,6 +174,29 @@ sub _build_out_dir {
   return $out_dir // '';
 }
 
+sub _expand_wildcards {
+  my $self = shift;
+  my (@files, %seen);
+
+  for my $file (@_) {
+    if (!-e $file and $file =~ /\*/) {
+      my @rel = split '/', $file;
+      my $glob = pop @rel;
+
+      for my $path (map { File::Spec->catdir($_, @rel) } @{$self->_app->static->paths}) {
+        my $cwd = Mojolicious::Plugin::AssetPack::Preprocessors::CWD->new($path);
+        push @files, grep { !$seen{$_} } map { join '/', @rel, $_ } sort glob $glob;
+      }
+    }
+    else {
+      push @files, $file;
+      $seen{$file} = 1;
+    }
+  }
+
+  return @files;
+}
+
 sub _find {
   my $needle = pop;
   my $self   = shift;
@@ -309,6 +355,11 @@ sub _source_for_url {
   return $asset;
 }
 
+sub _unlink_packed {
+  my ($self, $file) = @_;
+  unlink File::Spec->catfile($self->out_dir, $file);
+}
+
 # utils
 sub _ext { local $_ = File::Basename::basename($_[0]); /\.(\w+)$/ ? $1 : 'unknown'; }
 
@@ -329,7 +380,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.55
+0.56
 
 =head1 SYNOPSIS
 
@@ -342,6 +393,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
   # define assets: $moniker => @real_assets
   app->asset('app.js' => '/js/foo.js', '/js/bar.js', '/js/baz.coffee');
+  app->asset->purge; # remove old packed files
   app->start;
 
 See also L<Mojolicious::Plugin::AssetPack::Manual::Assets> for more
@@ -461,12 +513,6 @@ Default is false in "development" L<mode|Mojolicious/mode> and true otherwise.
 
 See also L<Mojolicious::Plugin::AssetPack::Manual::Modes>.
 
-=head2 preprocessors
-
-  $obj = $self->preprocessors;
-
-Holds a L<Mojolicious::Plugin::AssetPack::Preprocessors> object.
-
 =head2 out_dir
 
   $str = $self->out_dir;
@@ -477,6 +523,12 @@ Holds the path to the directory where packed files can be written.
 Defaults to empty string if no directory can be found, which again results in
 keeping all packed files in memory.
 
+=head2 preprocessors
+
+  $obj = $self->preprocessors;
+
+Holds a L<Mojolicious::Plugin::AssetPack::Preprocessors> object.
+
 =head1 METHODS
 
 =head2 add
@@ -514,6 +566,18 @@ Use this method to manually register a preprocessor.
 See L<Mojolicious::Plugin::AssetPack::Preprocessor::Browserify/SYNOPSIS>
 for example usage.
 
+=head2 purge
+
+  $self = $self->purge({always => $bool});
+
+Used to purge old packed files. This is useful if you want to avoid filling up
+L</out_dir> with many versions of the packed file.
+
+C<always> default to true if in "development" L<mode|Mojolicious/mode> and
+false otherwise.
+
+This method is EXPERIMENTAL and can change, be removed at any time.
+
 =head2 register
 
   plugin AssetPack => {
