@@ -11,6 +11,8 @@ sub t {
   my ($class, $args) = @_;
   my $t = Test::Mojo->new(Mojolicious->new);
 
+  $args->{log} ||= [];
+  $t->app->log->on(message => sub { push @{$args->{log}}, $_[2] });
   $t->app->static->paths([Cwd::abs_path(File::Spec->catdir(dirname($0), 'public'))]);
   $t->app->plugin(AssetPack => $args || {});
   $t->app->routes->get("/test1" => 'test1');
